@@ -21,6 +21,7 @@
 #ifndef vte_debug_h_included
 #define vte_debug_h_included
 
+#include <config.h>
 
 #include <glib.h>
 
@@ -48,7 +49,8 @@ typedef enum {
 	VTE_DEBUG_ALLY		= 1 << 18,
 	VTE_DEBUG_ADJ		= 1 << 19,
 	VTE_DEBUG_PANGOCAIRO    = 1 << 20,
-	VTE_DEBUG_WIDGET_SIZE   = 1 << 21
+	VTE_DEBUG_WIDGET_SIZE   = 1 << 21,
+        VTE_DEBUG_BG            = 1 << 22
 } VteDebugFlags;
 
 void _vte_debug_init(void);
@@ -76,7 +78,7 @@ _vte_debug_on(VteDebugFlags flags)
 #include <glib/gstdio.h>
 static void _vte_debug_print(guint flags, const char *fmt, ...)
 {
-	if (_vte_debug_on (flags)) {
+	_VTE_DEBUG_IF(flags) {
 		va_list  ap;
 		va_start (ap, fmt);
 		g_vfprintf (stderr, fmt, ap);
